import { mapGetters, mapActions } from 'vuex';
import store from './store';

export default {
  props: {
    operateId: {
      type: Number,
    },
  },
  created() {
    store.install(this.$store);
  },
  mounted() {
    if (this.dashboardArea && !this.dashboardArea.length) {
      this.fetchDashboardAreaList({
        operateId: null,
      });
    }
  },
  watch: {
    operateId(val) {
      this.fetchDashboardAreaList({
        operateId: val,
      });
    },
  },
  computed: {
    ...mapGetters('dashboardArea', ['dashboardArea']),
  },
  methods: {
    ...mapActions('dashboardArea', ['fetchDashboardAreaList']),
    getAreaName(id) {
      let item = this.dashboardArea.find(area => area.id === id);
      if (item) {
        return item.areaName;
      } else {
        return '';
      }
    },
    getAreaOperatorInfo(id) {
      let item = this.dashboardArea.find(area => area.id === id);
      if (item) {
        return {
          rechargeOperateId: item.rechargeOperateId,
          rechargeOperateName: item.rechargeOperateName,
        };
      } else {
        return null;
      }
    },
  },
};
